import { getCanvasSessionKey } from "./utils.js";
function isSessionObject(obj) {
    return (typeof obj === "object" &&
        typeof obj.app === "string" &&
        typeof obj.sessionPrivateKey === "string" &&
        typeof obj.expiration === "number");
}
export function getSessionObject(data, signerAddress) {
    const sessionKey = getCanvasSessionKey(signerAddress);
    const item = localStorage.getItem(sessionKey);
    if (item === null) {
        return null;
    }
    let sessionObject;
    try {
        sessionObject = JSON.parse(item);
    }
    catch (err) {
        localStorage.removeItem(sessionKey);
        return null;
    }
    if (!isSessionObject(sessionObject)) {
        localStorage.removeItem(sessionKey);
        return null;
    }
    const { app, expiration } = sessionObject;
    if (data.uri !== app || expiration < Date.now()) {
        localStorage.removeItem(sessionKey);
        return null;
    }
    return sessionObject;
}
export function setSessionObject(signerAddress, sessionObject) {
    const sessionKey = getCanvasSessionKey(signerAddress);
    localStorage.setItem(sessionKey, JSON.stringify(sessionObject));
}
export function removeSessionObject(signerAddress) {
    const sessionKey = getCanvasSessionKey(signerAddress);
    localStorage.removeItem(sessionKey);
}
